=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2005-09-29 21:03:18 +0000
+++ bzrlib/branch.py	2005-09-29 21:13:03 +0000
@@ -40,7 +40,7 @@
 from bzrlib.store.compressed_text import CompressedTextStore
 from bzrlib.store.text import TextStore
 from bzrlib.store.weave import WeaveStore
-from bzrlib.transport import Transport
+from bzrlib.transport import Transport, get_transport
 import bzrlib.xml5
 import bzrlib.ui
 
@@ -131,7 +131,7 @@
     @staticmethod
     def open(base):
         """Open an existing branch, rooted at 'base' (url)"""
-        t = bzrlib.transport.transport(base)
+        t = get_transport(base)
         return _Branch(t)
 
     @staticmethod
@@ -140,14 +140,14 @@
         
         This probes for a branch at url, and searches upwards from there.
         """
-        t = bzrlib.transport.transport(url)
+        t = get_transport(url)
         t = find_branch_root(t)
         return _Branch(t)
 
     @staticmethod
     def initialize(base):
         """Create a new branch, rooted at 'base' (url)"""
-        t = bzrlib.transport.transport(base)
+        t = get_transport(base)
         return _Branch(t, init=True)
 
     def setup_caching(self, cache_root):
@@ -1286,6 +1286,8 @@
         if base is None:
             base = mkdtemp()
             init = True
+        if isinstance(base, basestring):
+            base = get_transport(base)
         _Branch.__init__(self, base, init=init)
         for d in dirs:
             self._transport.mkdir(d)

=== modified file 'bzrlib/selftest/teststore.py'
--- bzrlib/selftest/teststore.py	2005-09-29 20:54:18 +0000
+++ bzrlib/selftest/teststore.py	2005-09-29 21:13:03 +0000
@@ -92,12 +92,12 @@
     check_equals(tester, store, ['b', 'd', 'c'], ['other', None, 'something'],
             permit_failure=True)
 
-def get_compressed_store():
-    t = LocalTransport('.')
+def get_compressed_store(path='.'):
+    t = LocalTransport(path)
     return CompressedTextStore(t)
 
-def get_text_store():
-    t = LocalTransport('.')
+def get_text_store(path='.'):
+    t = LocalTransport(path)
     return TextStore(t)
 
 class TestCompressedTextStore(TestCaseInTempDir):
@@ -118,10 +118,10 @@
     def test_copy_all(self):
         """Test copying"""
         os.mkdir('a')
-        store_a = CompressedTextStore('a')
+        store_a = get_text_store('a')
         store_a.add('foo', '1')
         os.mkdir('b')
-        store_b = CompressedTextStore('b')
+        store_b = get_text_store('b')
         copy_all(store_a, store_b)
         self.assertEqual(store_a['1'].read(), 'foo')
         self.assertEqual(store_b['1'].read(), 'foo')
@@ -149,10 +149,10 @@
     def test_copy_all(self):
         """Test copying"""
         os.mkdir('a')
-        store_a = TextStore('a')
+        store_a = get_text_store('a')
         store_a.add('foo', '1')
         os.mkdir('b')
-        store_b = TextStore('b')
+        store_b = get_text_store('b')
         copy_all(store_a, store_b)
         self.assertEqual(store_a['1'].read(), 'foo')
         self.assertEqual(store_b['1'].read(), 'foo')

=== modified file 'bzrlib/store/text.py'
--- bzrlib/store/text.py	2005-09-29 20:54:18 +0000
+++ bzrlib/store/text.py	2005-09-29 21:13:03 +0000
@@ -37,7 +37,7 @@
     the hash is used as the name, or something else known to be unique,
     such as a UUID.
 
-    Files are stored gzip compressed, with no delta compression.
+    Files are stored uncompressed, with no delta compression.
 
     """
 
@@ -128,7 +128,6 @@
         rel_paths = [self._relpath(fid) for fid in fileids]
         is_requested = []
 
-        #mutter('CompressedTextStore.get(permit_failure=%s)' % permit_failure)
         if permit_failure:
             existing_paths = []
             for path, has in zip(rel_paths,
@@ -150,11 +149,7 @@
             while not is_requested[count]:
                 yield None
                 count += 1
-            if hasattr(f, 'tell'):
-                yield gzip.GzipFile(mode='rb', fileobj=f)
-            else:
-                sio = StringIO(f.read())
-                yield gzip.GzipFile(mode='rb', fileobj=sio)
+            yield f
             count += 1
 
         while count < len(is_requested):

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2005-09-18 21:09:19 +0000
+++ bzrlib/transport/__init__.py	2005-09-29 21:13:03 +0000
@@ -340,7 +340,7 @@
         raise NotImplementedError
 
 
-def transport(base):
+def get_transport(base):
     global _protocol_handlers
     if base is None:
         base = '.'

